==> ovirt-engine-3.5.6.2.tar.gz: frontend/webadmin/modules/uicommonweb/src/main/java/org/ovirt/engine/ui/uicommonweb/models/datacenters/BaseNetworkQosModel.java <==
package org.ovirt.engine.ui.uicommonweb.models.datacenters;

import org.ovirt.engine.core.common.businessentities.network.NetworkQoS;
import org.ovirt.engine.ui.uicommonweb.models.Model;
import org.ovirt.engine.ui.uicompat.Event;
import org.ovirt.engine.ui.uicompat.EventArgs;
import org.ovirt.engine.ui.uicompat.IEventListener;
import org.ovirt.engine.ui.uicompat.PropertyChangedEventArgs;

public class BaseNetworkQosModel extends Model {

    private NetworkQosParametersModel inbound;
    private NetworkQosParametersModel outbound;

    protected NetworkQoS networkQoS;

    public NetworkQosParametersModel getInbound() {
        return inbound;
    }

    public void setInbound(NetworkQosParametersModel inbound) {
        this.inbound = inbound;
    }

    public NetworkQosParametersModel getOutbound() {
        return outbound;
    }

    public void setOutbound(NetworkQosParametersModel outbound) {
        this.outbound = outbound;
    }

    public BaseNetworkQosModel() {
        setInbound(new NetworkQosParametersModel());
        setOutbound(new NetworkQosParametersModel());
        getPropertyChangedEvent().addListener(new IEventListener() {

            @Override
            public void eventRaised(Event ev, Object sender, EventArgs args) {
                if ("IsChangable".equals(((PropertyChangedEventArgs) args).propertyName)) { //$NON-NLS-1$
                    boolean value = getIsChangable();
                    getInbound().setIsChangable(value);
                    getOutbound().setIsChangable(value);
                }
            }
        });
    }

    public void init(NetworkQoS qos) {
        if (qos == null) {
            networkQoS = new NetworkQoS();
        } else {
            networkQoS = qos;
        }

        if (networkQoS.getInboundAverage() == null
                || networkQoS.getInboundPeak() == null
                || networkQoS.getInboundBurst() == null) {
            getInbound().getEnabled().setEntity(false);
        } else {
            getInbound().getAverage().setEntity(networkQoS.getInboundAverage());
            getInbound().getPeak().setEntity(networkQoS.getInboundPeak());
            getInbound().getBurst().setEntity(networkQoS.getInboundBurst());
        }

        if (networkQoS.getOutboundAverage() == null
                || networkQoS.getOutboundPeak() == null
                || networkQoS.getOutboundBurst() == null) {
            getOutbound().getEnabled().setEntity(false);
        } else {
            getOutbound().getAverage().setEntity(networkQoS.getOutboundAverage());
            getOutbound().getPeak().setEntity(networkQoS.getOutboundPeak());
            getOutbound().getBurst().setEntity(networkQoS.getOutboundBurst());
        }
    }

    public boolean validate() {
        if (!getIsAvailable()) {
            return true;
        }

        getInbound().validate();
        getOutbound().validate();

        setIsValid(getInbound().getIsValid() && getOutbound().getIsValid());
        return getIsValid();
    }

    public NetworkQoS flush() {
        if (getInbound().getEnabled().getEntity()) {
            networkQoS.setInboundAverage(getInbound().getAverage().getEntity());
            networkQoS.setInboundPeak(getInbound().getPeak().getEntity());
            networkQoS.setInboundBurst(getInbound().getBurst().getEntity());
        } else {
            networkQoS.setInboundAverage(null);
            networkQoS.setInboundPeak(null);
            networkQoS.setInboundBurst(null);
        }

        if (getOutbound().getEnabled().getEntity()) {
            networkQoS.setOutboundAverage(getOutbound().getAverage().getEntity());
            networkQoS.setOutboundPeak(getOutbound().getPeak().getEntity());
            networkQoS.setOutboundBurst(getOutbound().getBurst().getEntity());
        } else {
            networkQoS.setOutboundAverage(null);
            networkQoS.setOutboundPeak(null);
            networkQoS.setOutboundBurst(null);
        }

        return networkQoS;
    }

}

==> ovirt-engine-4.0.6.tar.gz: frontend/webadmin/modules/uicommonweb/src/main/java/org/ovirt/engine/ui/uicommonweb/models/datacenters/BaseNetworkQosModel.java <==
package org.ovirt.engine.ui.uicommonweb.models.datacenters;

import org.ovirt.engine.core.common.businessentities.network.NetworkQoS;
import org.ovirt.engine.ui.uicommonweb.models.Model;
import org.ovirt.engine.ui.uicompat.Event;
import org.ovirt.engine.ui.uicompat.IEventListener;
import org.ovirt.engine.ui.uicompat.PropertyChangedEventArgs;

public class BaseNetworkQosModel extends Model {

    private NetworkQosParametersModel inbound;
    private NetworkQosParametersModel outbound;

    protected NetworkQoS networkQoS;

    public NetworkQosParametersModel getInbound() {
        return inbound;
    }

    public void setInbound(NetworkQosParametersModel inbound) {
        this.inbound = inbound;
    }

    public NetworkQosParametersModel getOutbound() {
        return outbound;
    }

    public void setOutbound(NetworkQosParametersModel outbound) {
        this.outbound = outbound;
    }

    public BaseNetworkQosModel() {
        setInbound(new NetworkQosParametersModel());
        setOutbound(new NetworkQosParametersModel());
        getPropertyChangedEvent().addListener(new IEventListener<PropertyChangedEventArgs>() {

            @Override
            public void eventRaised(Event<? extends PropertyChangedEventArgs> ev, Object sender, PropertyChangedEventArgs args) {
                if ("IsChangable".equals(args.propertyName)) { //$NON-NLS-1$
                    boolean value = getIsChangable();
                    getInbound().setIsChangeable(value);
                    getOutbound().setIsChangeable(value);
                }
            }
        });
    }

    public void init(NetworkQoS qos) {
        if (qos == null) {
            networkQoS = new NetworkQoS();
        } else {
            networkQoS = qos;
        }

        if (networkQoS.getInboundAverage() == null
                || networkQoS.getInboundPeak() == null
                || networkQoS.getInboundBurst() == null) {
            getInbound().getEnabled().setEntity(false);
        } else {
            getInbound().getAverage().setEntity(networkQoS.getInboundAverage());
            getInbound().getPeak().setEntity(networkQoS.getInboundPeak());
            getInbound().getBurst().setEntity(networkQoS.getInboundBurst());
        }

        if (networkQoS.getOutboundAverage() == null
                || networkQoS.getOutboundPeak() == null
                || networkQoS.getOutboundBurst() == null) {
            getOutbound().getEnabled().setEntity(false);
        } else {
            getOutbound().getAverage().setEntity(networkQoS.getOutboundAverage());
            getOutbound().getPeak().setEntity(networkQoS.getOutboundPeak());
            getOutbound().getBurst().setEntity(networkQoS.getOutboundBurst());
        }
    }

    public boolean validate() {
        if (!getIsAvailable()) {
            return true;
        }

        getInbound().validate();
        getOutbound().validate();

        setIsValid(getInbound().getIsValid() && getOutbound().getIsValid());
        return getIsValid();
    }

    public NetworkQoS flush() {
        if (getInbound().getEnabled().getEntity()) {
            networkQoS.setInboundAverage(getInbound().getAverage().getEntity());
            networkQoS.setInboundPeak(getInbound().getPeak().getEntity());
            networkQoS.setInboundBurst(getInbound().getBurst().getEntity());
        } else {
            networkQoS.setInboundAverage(null);
            networkQoS.setInboundPeak(null);
            networkQoS.setInboundBurst(null);
        }

        if (getOutbound().getEnabled().getEntity()) {
            networkQoS.setOutboundAverage(getOutbound().getAverage().getEntity());
            networkQoS.setOutboundPeak(getOutbound().getPeak().getEntity());
            networkQoS.setOutboundBurst(getOutbound().getBurst().getEntity());
        } else {
            networkQoS.setOutboundAverage(null);
            networkQoS.setOutboundPeak(null);
            networkQoS.setOutboundBurst(null);
        }

        return networkQoS;
    }

}
